Developer guide
===============

This Section describes the main library structure and meaning, to serve
as a reference for planning extensions and modifications to the core
library. It does not provide user documentation to use ``otupy`` in your
projects. For code documentation, see :any:`api`.

.. toctree::
   :maxdepth: 1

   mapping
   naming
   corecomponents
   types
